@@ -153,7 +153,7 @@ def text_to_hashes(s, word_n_grams, bucketSize):
     s_bytes = s.encode("utf-8")
 
     # allocate the output buffer
-    o_bytes = (c_uint32 * (2 * len(s_bytes)))()
+    o_bytes = (c_int32 * (word_n_grams * len(s_bytes)))()
     o_bytes_count = len(o_bytes)
 
     # identify paragraphs
@@ -161,10 +161,10 @@ def text_to_hashes(s, word_n_grams, bucketSize):
 
     # check if no error has happened
     if -1 == o_len or o_len > o_bytes_count:
-        return ''
+        return None
 
     # return numpy array without copying
-    return np.frombuffer(o_bytes, dtype=c_uint32, count=o_len)
+    return np.frombuffer(o_bytes, dtype=c_int32, count=o_len)
 
 
 def text_to_token_with_offsets(s, text_to_token_f, split_byte):    
@@ -264,5 +264,9 @@ def utf8text_to_ids_with_offsets(h, s_bytes, max_len, unk = 0, no_padding = Fals
     out_count = min (o_bytes_count, t_count) if no_padding else o_bytes_count
     # return numpy array without copying
     return ( np.frombuffer(o_bytes, dtype=c_uint32, count = out_count), 
-             np.frombuffer(o_bytes_starts, dtype=c_uint32, count = out_count), 
-             np.frombuffer(o_bytes_ends, dtype=c_uint32, count = out_count) )
+             np.frombuffer(o_bytes_starts, dtype=c_int32, count = out_count), 
+             np.frombuffer(o_bytes_ends, dtype=c_int32, count = out_count) )
+
+
+def change_settings_dummy_prefix(h, add_prefix):
+    blingfire.SetNoDummyPrefix(c_void_p(h), c_int(not add_prefix))
